Literature
==========

The following references give some theoretical background about the methods being used in the Acoular program package.

.. _Albertson1950: 

Albertson, M. L. , Dai, Y. B., Jensen, R. A., and Hunter Rouse (1950). Diffusion of Submerged Jets. Transactions of the American Society of Civil Engineers, 115(1), 639-664.

.. _BrooksHumphreys2006:

Brooks, T. F., & Humphreys, W. M. (2006). A deconvolution approach for the mapping of acoustic sources (DAMAS) determined from phased microphone arrays. Journal of Sound and Vibration, 294(4-5), 856-879. 

.. _Capon1969:

Capon, J. (1969). High-resolution frequency-wavenumber spectrum analysis. Proceedings of the IEEE, 57(8), 1408-1418.

.. _Cousson2019:

R. Cousson, Q. Leclère, M.-A. Pallas, and M. Berengier (2019). A time domain clean approach for the identification of acoustic moving sources. Journal of Sound and Vibration, 443, 47-62. doi:10.1016/j.jsv.2018.11.026.

.. _Dougherty2014:

Dougherty, R. P. (2014). Functional Beamforming. In: Proceedings of the Berlin Beamforming Conference 2014.

.. _Hoegbom1974:

Högbom, J. A. (1974). Aperture synthesis with a non-regular distribution of interferometer baselines. Astronomy and Astrophysics Supplement, 15(3), 417-426.

.. _Sarradj2005:

Sarradj, E., Schulze, C., Zeibig, A. (2005): Identification of noise source mechanisms using orthogonal beamforming. Proceedings of International Congress on Noise and Vibration Emerging Methods (NOVEM 2005).

.. _Sarradj2010:

Sarradj, E. (2010). A fast signal subspace approach for the determination of absolute levels from phased microphone array measurements. Journal of Sound and Vibration, 329(9), 1553-1569.

.. _Sarradj2012:

Sarradj, E. (2012). Three-Dimensional Acoustic Source Mapping with Different Beamforming Steering Vector Formulations. Advances in Acoustics and Vibration, 2012, 1-12.

.. _Schmidt1986:

R. Schmidt (1986). Multiple emitter location and signal parameter estimation. IEEE Trans Antennas Propag. 34(3), 276-280.

.. _Sijtsma2007:

Sijtsma, P. (2007). CLEAN based on spatial source coherence. International Journal of Aeroacoustics, 6(4), 357-374.

.. _Wefers2015:

Wefers, F. (2015). Partitioned Convolution Algorithms for Real-Time Auralization. Logos Verlag. isbn:3832539433.

.. _Yardibi2008:

Yardibi, T., Li, J., Stoica, P., & Cattafesta, L. N. (2008). Sparsity constrained deconvolution approaches for acoustic source mapping. The Journal of the Acoustical Society of America, 123(5), 2631-2642.
